Documentation
¶
Index ¶
- func HTMLOutagesHandler(c *gin.Context)
- func HTMLRestartsHandler(c *gin.Context)
- func HTMLTicketsHandler(c *gin.Context)
- func HTMLUpdatesHandler(c *gin.Context)
- func HTMLVersionsHandler(c *gin.Context)
- func InputOutageHandler(c *gin.Context)
- func InputRestartHandler(c *gin.Context)
- func InputUpdateHandler(c *gin.Context)
- func InputUpdateHandlerByID(c *gin.Context)
- func InputUpdateVersionsHandler(c *gin.Context)
- func InputVersionHandlerByWebVersion(c *gin.Context)
- func InputVersionsHandler(c *gin.Context)
- type ClientRestart
- type ClientUpdate
- type OutageRecord
- type Ticket
- type Versions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HTMLOutagesHandler ¶
HTMLOutagesHandler returns a html page with all outage historys in a given period
func HTMLRestartsHandler ¶
func HTMLTicketsHandler ¶
func HTMLUpdatesHandler ¶
func HTMLVersionsHandler ¶
func InputOutageHandler ¶
InputOutageHandler saves an outage message to the outage_history collection
func InputRestartHandler ¶
func InputUpdateHandler ¶
func InputUpdateHandlerByID ¶
func InputVersionsHandler ¶
Types ¶
type ClientRestart ¶
type ClientUpdate ¶
type ClientUpdate struct {
ClientId string `json:"client_id" binding:"Required"`
Platform string `json:"platform" binding:"Required"`
Date string `json:"date"`
PreviousVersion string `json:"previous_version" binding:"Required"`
UpdatedVersion string `json:"updated_version" binding:"Required"`
User string `json:"user" binding:"Required"`
}
type OutageRecord ¶
type OutageRecord struct {
ClientID string `json:"client_id" binding:"Required"`
CreationDate string
ServerAddress string `json:"server_address"`
Description string `json:"description"`
TopClients string `json:"top_clients"`
User string `json:"user" binding:"Required"`
Agent string `json:"agent" binding:"Required"`
State string `json:"state" binding:"Required"`
Duration time.Duration
}
OutageRecord is the structure for an outage message provenient from Nagios or another monitoring tool
Click to show internal directories.
Click to hide internal directories.